@@ -3,7 +3,7 @@ import pandas as pd
 from sqlalchemy import create_engine, MetaData, Table, text, select
 from sqlalchemy.pool import NullPool
 
-__all__=['connect_to_db','get_data_from_db']
+__all__=['connect_to_db','get_data_from_db','get_pandas_df_from_db']
 
 
 logger = logging.getLogger(__name__)
@@ -49,7 +49,7 @@ def get_data_from_db(sql_select_query):
         data = text(sql_select_query)
         print('fetcheando')
         data = connection.execute(data).fetchall()
-        'print armando diccionario'
+        print('print armando diccionario')
         data = [dict(zip(row.keys(), row)) for row in data]
         print(f"- Total leads to work: {len(data)}")
     except Exception as exception:
