@@ -210,7 +210,6 @@ def set_bv_target_column(df):
     else:
         logger.error('No BV column found')
         raise Exception('No BV column found!!!!!')
-    #   df = df[df.BV < 40]
     return df
 
 def set_bv_fake_column(df):
@@ -330,10 +329,16 @@ def process_bulkstatus(df):
         df.loc[(df['BulkStatus'] == 6), 'is_OOO'] = 1
         df['is_NN']=0
         df.loc[(df['BulkStatus'] == 12), 'is_NN'] = 1
+        df['is_New']=0
+        df.loc[(df['BulkStatus'] == 0), 'is_New'] = 1        
+        df['is_FU']=0
+        df.loc[(df['BulkStatus'] == 1), 'is_FU'] = 1        
         df.drop(labels=['BulkStatus'],axis=1,inplace=True)
         logger.info('Deleted BulkStatus column')
-        logger.info(df['is_OOO'].value_counts())
-        logger.info(df['is_NN'].value_counts())
+        logger.info(f' OOO: {df['is_OOO'].value_counts()}')
+        logger.info(f' NN: {df['is_NN'].value_counts()}')
+        logger.info(f' New: {df['is_New'].value_counts()}')
+        logger.info(f' FU: {df['is_FU'].value_counts()}')
     else:
         logger.info('Column not present')
     return df
